from __future__ import absolute_import, unicode_literals


class Meta(object):
    """A simple object subclass to allow for a Meta class to be added
    to CompositeField if none is declared.
    """
    pass
